@@ -52,7 +52,6 @@ except ImportError:  # 2.x compatibility.
 from airflow.cli.cli_config import (
     ARG_DAG_ID,
     ARG_OUTPUT_PATH,
-    ARG_SUBDIR,
     ARG_VERBOSE,
     ActionCommand,
     Arg,
@@ -77,13 +76,13 @@ from airflow.utils.state import TaskInstanceState
 
 if TYPE_CHECKING:
     import argparse
+    from collections.abc import Sequence
 
     from kubernetes import client
     from kubernetes.client import models as k8s
     from sqlalchemy.orm import Session
 
     from airflow.executors import workloads
-    from airflow.executors.base_executor import CommandType
     from airflow.models.taskinstance import TaskInstance
     from airflow.models.taskinstancekey import TaskInstanceKey
     from airflow.providers.cncf.kubernetes.executors.kubernetes_executor_types import (
@@ -94,6 +93,16 @@ if TYPE_CHECKING:
         AirflowKubernetesScheduler,
     )
 
+
+if AIRFLOW_V_3_0_PLUS:
+    from airflow.cli.cli_config import ARG_BUNDLE_NAME
+
+    ARG_COMPAT = ARG_BUNDLE_NAME
+else:
+    from airflow.cli.cli_config import ARG_SUBDIR  # type: ignore[attr-defined]
+
+    ARG_COMPAT = ARG_SUBDIR
+
 # CLI Args
 ARG_NAMESPACE = Arg(
     ("--namespace",),
@@ -128,7 +137,7 @@ KUBERNETES_COMMANDS = (
         help="Generate YAML files for all tasks in DAG. Useful for debugging tasks without "
         "launching into a cluster",
         func=lazy_load_command("airflow.providers.cncf.kubernetes.cli.kubernetes_command.generate_pod_yaml"),
-        args=(ARG_DAG_ID, ARG_LOGICAL_DATE, ARG_SUBDIR, ARG_OUTPUT_PATH, ARG_VERBOSE),
+        args=(ARG_DAG_ID, ARG_LOGICAL_DATE, ARG_COMPAT, ARG_OUTPUT_PATH, ARG_VERBOSE),
     ),
 )
 
@@ -245,7 +254,7 @@ class KubernetesExecutor(BaseExecutor):
     def execute_async(
         self,
         key: TaskInstanceKey,
-        command: CommandType,
+        command: Any,
         queue: str | None = None,
         executor_config: Any | None = None,
     ) -> None:
@@ -283,7 +292,7 @@ class KubernetesExecutor(BaseExecutor):
         ti = workload.ti
         self.queued_tasks[ti.key] = workload
 
-    def _process_workloads(self, workloads: list[workloads.All]) -> None:
+    def _process_workloads(self, workloads: Sequence[workloads.All]) -> None:
         from airflow.executors.workloads import ExecuteTask
 
         # Airflow V3 version
@@ -482,7 +491,7 @@ class KubernetesExecutor(BaseExecutor):
             ).items
             if not pod_list:
                 raise RuntimeError("Cannot find pod for ti %s", ti)
-            elif len(pod_list) > 1:
+            if len(pod_list) > 1:
                 raise RuntimeError("Found multiple pods for ti %s: %s", ti, pod_list)
             res = client.read_namespaced_pod_log(
                 name=pod_list[0].metadata.name,
