@@ -28,11 +28,11 @@ import yaml
 from kubernetes.utils import create_from_yaml
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.cncf.kubernetes.hooks.kubernetes import KubernetesHook
 from airflow.providers.cncf.kubernetes.kubernetes_helper_functions import should_retry_creation
 from airflow.providers.cncf.kubernetes.utils.delete_from import delete_from_yaml
 from airflow.providers.cncf.kubernetes.utils.k8s_resource_iterator import k8s_resource_iterator
+from airflow.providers.cncf.kubernetes.version_compat import BaseOperator
 
 if TYPE_CHECKING:
     from kubernetes.client import ApiClient, CustomObjectsApi
@@ -99,8 +99,7 @@ class KubernetesResourceBaseOperator(BaseOperator):
     def get_namespace(self) -> str:
         if self._namespace:
             return self._namespace
-        else:
-            return self.hook.get_namespace() or "default"
+        return self.hook.get_namespace() or "default"
 
     def get_crd_fields(self, body: dict) -> tuple[str, str, str, str]:
         api_version = body["apiVersion"]
